@@ -1,24 +1,26 @@
-#' Complete Themes
+#' List of Available Themes
 #' 
-#' \code{ggtern} ships with a number of complete themes:
+#' \code{ggtern} ships with a number of complete themes, summarized as follows. 
+#' These themes combine the base themes available to \code{ggplot2} and a number of NEW themes, which
+#' are unique to \code{ggtern}.
 #' \itemize{
 #'  \item{ Black and White Theme:}{ 
-#'    \code{\link[=theme_tern_bw]{theme_bw(...)}}
+#'    \code{\link[=theme_bw]{theme_bw(...)}}
 #'  }
 #'  \item{Minimal Theme:}{
-#'    \code{\link[=theme_tern_minimal]{theme_minimal(...)}}
+#'    \code{\link[=theme_minimal]{theme_minimal(...)}}
 #'  }
 #'  \item{Classic Theme:}{
-#'    \code{\link[=theme_tern_classic]{theme_classic(...)}}
+#'    \code{\link[=theme_classic]{theme_classic(...)}}
 #'  }
 #'  \item{Gray and White Theme:}{
-#'    \code{\link[=theme_tern_gray]{theme_gray(...)}}
+#'    \code{\link[=theme_gray]{theme_gray(...)}}
 #'  }
 #'  \item{Red, Green, Blue and White Theme:}{
-#'    \code{\link[=theme_tern_rgbw]{theme_rgbw(...)}}
+#'    \code{\link[=theme_rgbw]{theme_rgbw(...)}}
 #'  }
 #'  \item{Red, Green, Blue and Gray Theme:}{
-#'    \code{\link[=theme_tern_rgbg]{theme_rgbg(...)}}
+#'    \code{\link[=theme_rgbg]{theme_rgbg(...)}}
 #'  }
 #'  \item{Dark Theme:}{
 #'    \code{\link[=theme_dark]{theme_dark(...)}}
@@ -32,10 +34,29 @@
 #'  \item{Theme with Only Black Lines:}{
 #'    \code{\link[=theme_linedraw]{theme_linedraw(...)}}
 #'  }
+#'  \item{Matrix Theme:}{
+#'    \code{\link[=theme_matrix]{theme_matrix(...)}}
+#'  }
+#'  \item{Tropical Theme:}{
+#'    \code{\link[=theme_tropical]{theme_tropical(...)}}
+#'  }
+#'  \item{BlueLight Theme:}{
+#'    \code{\link[=theme_bluelight]{theme_bluelight(...)}}
+#'  }
+#'  \item{BlueDark Theme:}{
+#'    \code{\link[=theme_bluedark]{theme_bluedark(...)}}
+#'  }
+#'  \item{Black Vermillion Blue Theme (White Background):}{
+#'    \code{\link[=theme_bvbw]{theme_bvbw(...)}}
+#'  }
+#'  \item{Black Vermillion Blue Theme (Grey Background):}{
+#'    \code{\link[=theme_bvbg]{theme_bvbg(...)}}
+#'  }
 #' }
+#' @seealso \code{\link{ggtern_themes}}
+#' @author Nicholas Hamilton
 #' @rdname theme_complete
 #' @name theme_complete
-#' @author Nicholas Hamilton
 NULL
 
 #' ggtern themes
@@ -50,11 +71,13 @@ NULL
 #'
 #' \item{\code{theme_gray}}{
 #' The signature ggplot2 theme with a grey background and white gridlines,
-#' designed to put the data forward yet make comparisons easy.}
+#' designed to put the data forward yet make comparisons easy.
+#' }
 #'
 #' \item{\code{theme_bw}}{
 #' The classic dark-on-light ggplot2 theme. May work better for presentations
-#' displayed with a projector.}
+#' displayed with a projector.
+#' }
 #'
 #' \item{\code{theme_linedraw}}{
 #' A theme with only black lines of various widths on white backgrounds,
@@ -64,7 +87,8 @@ NULL
 #'
 #' \item{\code{theme_light}}{
 #' A theme similar to \code{theme_linedraw} but with light grey lines and axes,
-#' to direct more attention towards the data.}
+#' to direct more attention towards the data.
+#' }
 #'
 #' \item{\code{theme_dark}}{
 #' The dark cousin of \code{theme_light}, with similar line sizes but a dark background. 
@@ -98,30 +122,66 @@ NULL
 #' \item{\code{theme_custom}}{
 #' Theme with custom basic colours
 #' }
+#' 
+#' \item{\code{theme_matrix}}{
+#' Theme with very dark background and bright green features
+#' }
+#' 
+#' \item{\code{theme_tropical}}{
+#' Theme with tropical colours
+#' }
+#' 
+#' \item{\code{theme_bluelight}}{
+#' A blue theme with light background and dark features
+#' }
+#' 
+#' \item{\code{theme_bluedark}}{
+#' A blue theme with dark background and light features
+#' }
+#' 
+#' \item{\code{theme_bvbw}}{
+#' A black/vermillion/blue theme with white background, for colorblind sensitive readers, see references.
+#' }
+#' 
+#' \item{\code{theme_bvbg}}{
+#' A black/vermillion/blue theme with grey background, for colorblind sensitive readers, see references.
+#' }
+#' 
 #' }
 #'
 #' @examples
-#' data(Feldspar)
-#' p <- ggtern(Feldspar,aes(Ab,An,Or)) + 
-#'      geom_point(aes(colour=T.C,size=P.Gpa)) + 
-#'      facet_wrap(~Feldspar)
+#' #Create a list of the theme suffixes
+#' themesOrg = c('gray','bw','linedraw','light',
+#'               'dark','minimal','classic','void')
+#' themesNew = c('custom','darker','rgbw','rgbg','tropical',
+#'               'matrix','bluelight','bluedark','bvbw','bvbg')
 #' 
-#' #Uncomment to run
-#' p + theme_gray()
-#' p + theme_rgbg()
-#' p + theme_dark()
-#' @aliases theme_tern_gray theme_tern_grey theme_grey theme_tern_bw theme_tern_classic theme_tern_rgbg theme_tern_rgbw theme_tern_minimal
+#' #Iterate over all the suffixes, creating a list of plots
+#' plotThemes = function(themes){
+#'    grobs = lapply(themes,function(x){
+#'      thmName = sprintf("theme_%s",x)
+#'      thm = do.call(thmName,args=list(base_size=9))
+#'      df  = data.frame(label=thmName)
+#'      ggtern(df) + facet_wrap(~label) + thm
+#'    })
+#'    grobs
+#' }
+#' 
+#' #Arrange the Original Themes
+#' grid.arrange(grobs=plotThemes(themesOrg),top = "Collection of Themes (Original)")
+#' 
+#' #Arrange the New Themes
+#' grid.arrange(grobs=plotThemes(themesNew),top = "Collection of Themes (New Themes)")
+#' 
+#' @references 
+#' Okabe, Masataka, and Kei Ito. "How to make figures and presentations that are friendly to color blind people." 
+#' University of Tokyo (2002). http://jfly.iam.u-tokyo.ac.jp/color/
+#' 
+#' @author Nicholas Hamilton
 #' @name ggtern_themes
 #' @rdname ggtern_themes
 NULL
 
-#thm = base_ggtern_theme()
-#result = lapply(ls(thm),function(x){
-#  print(x)
-#  calc_element(x,thm)
-#})
-
-
 #' @rdname ggtern_themes
 #' @export
 theme_ggtern <- function(base_size = 11, base_family = ""){
@@ -140,9 +200,10 @@ theme_ggtern <- function(base_size = 11, base_family = ""){
     ##TERNARY PANEL
     tern.panel.background          = element_rect(),  #Panel is the triangular region
     tern.plot.background           = element_rect(), #Plot  is the rectangular outer region
+    tern.plot.latex                = getOption('tern.latex'), #Parse Labels as Latex
     
     ##AXIS ARROWS
-    #tern.axis                      = element_line(),
+    #tern.axis                     = element_line(),
     tern.axis.hshift               = getOption("tern.hshift"),
     tern.axis.vshift               = getOption("tern.vshift"),
     tern.axis.clockwise            = getOption("tern.clockwise"),
@@ -222,6 +283,7 @@ theme_gray  <- function(base_size = 11, base_family = ""){
   base = theme_ggtern(base_size = base_size, base_family = base_family) 
   base %+replace%
   theme(
+    tern.plot.background  = element_rect(size=NA,color=NA),
     tern.axis.arrow       = element_line(
       color               = calc_element('axis.text',base)$colour,
       lineend             = getOption('tern.arrow')
@@ -237,10 +299,10 @@ theme_grey <- theme_gray
 #' @export
 theme_bw <- function(base_size = 12, base_family = "") {
   base = ggplot2::theme_bw(base_size,base_family)
-  
   theme_ggtern(base_size,base_family) %+replace% 
   base %+replace%
   theme(
+    tern.plot.background  = element_rect(size=NA,color=NA),
     tern.axis.line = element_line(color = base$panel.border$colour)
   )
 }
@@ -271,6 +333,7 @@ theme_light <- function(base_size = 12, base_family = "") {
   theme_ggtern() %+replace%
     base %+replace%
     theme(
+      tern.plot.background  = element_rect(size=NA,color=NA),
       tern.axis.line        = baseline,
       tern.axis.ticks       = base$axis.ticks,
       tern.axis.ticks.minor = element_blank(),
@@ -286,17 +349,17 @@ theme_light <- function(base_size = 12, base_family = "") {
 #' @export
 theme_minimal <- function(base_size = 12, base_family = "") {
   theme_bw(base_size,base_family) %+replace%
-    ggplot2::theme_minimal(base_size,base_family) %+replace%
-    theme(
-      tern.axis.line        = element_line(),
-      tern.axis.line.T      = element_blank(),
-      tern.axis.line.L      = element_blank(),
-      tern.axis.line.R      = element_blank(),
-      tern.axis.ticks.major = element_blank(),
-      tern.axis.ticks.minor = element_blank(),
-      tern.axis.arrow       = element_blank(),
-      tern.axis.arrow.text  = element_blank()
-    )
+  ggplot2::theme_minimal(base_size,base_family) %+replace%
+  theme(
+    tern.axis.line        = element_line(),
+    tern.axis.line.T      = element_blank(),
+    tern.axis.line.L      = element_blank(),
+    tern.axis.line.R      = element_blank(),
+    tern.axis.ticks.major = element_blank(),
+    tern.axis.ticks.minor = element_blank(),
+    tern.axis.arrow       = element_blank(),
+    tern.axis.arrow.text  = element_blank()
+  )
 }
 
 #' @rdname ggtern_themes
@@ -327,6 +390,7 @@ theme_dark <- function(base_size = 12, base_family = "") {
   theme_ggtern(base_size,base_family) %+replace% 
   base %+replace%
   theme(
+    tern.plot.background  = element_rect(size=NA,color=NA),
     tern.axis.line  = element_line( colour = "grey40", size = 0.25),
     tern.axis.ticks = element_line( colour = "grey40", size = 0.25),
     tern.axis.ticks.minor = element_blank()
@@ -370,8 +434,8 @@ theme_darker <- function(base_size = 12, base_family = "") {
 #' @export
 theme_custom <- function(base_size             = 12,
                          base_family           = "",
-                         tern.plot.background  = 'white',
-                         tern.panel.background = 'grey92',
+                         tern.plot.background  = NULL,
+                         tern.panel.background = NULL,
                          col.T                 = 'black',
                          col.L                 = 'black',
                          col.R                 = 'black',
@@ -382,6 +446,7 @@ theme_custom <- function(base_size             = 12,
   
   #Elements to replace
   theme(
+    tern.plot.background    = element_rect(fill  = tern.plot.background,size=NA,color=NA),
     tern.panel.background   = element_rect(fill  = tern.panel.background),
     tern.panel.grid.major   = element_line(linetype=6,size=0.50),
     tern.panel.grid.major.T = element_line(color = col.T),
@@ -442,6 +507,125 @@ theme_rgbg <- function(base_size = 12, base_family = ""){
 }
 theme_rgb <- theme_rgbg
 
+#' @rdname ggtern_themes
+#' @export
+theme_matrix = function(base_size = 12, base_family = ""){
+    featA = 'green'; featAG = 'darkgreen'; featB = NA; featC = 'grey15'; featD = 'grey10'; featE = 'grey15'
+    theme_custom(base_size             = base_size, 
+                 base_family           = base_family, 
+                 tern.plot.background  = NULL, #FORCE INHERIT
+                 tern.panel.background = featC,
+                 col.T                 = featA,
+                 col.L                 = featA,
+                 col.R                 = featA,
+                 col.grid.minor        = featB) +
+    theme(text                    = element_text(color = featA),
+          plot.background         = element_rect(fill  = featD),
+          strip.background        = element_rect(color = featA, fill = featE),
+          strip.text              = element_text(color = featA),
+          tern.panel.grid.major.T = element_line(color = featAG),
+          tern.panel.grid.major.L = element_line(color = featAG),
+          tern.panel.grid.major.R = element_line(color = featAG),
+          tern.axis.arrow.show    = TRUE)
+}
+
+#' @rdname ggtern_themes
+#' @export
+theme_tropical = function(base_size = 12, base_family = ""){
+  col.T = '#fe8f0f'; col.L = '#f7325e'; col.R = '#7dc410'; col.text  = '#0264ed'; 
+  col.bg.strip = 'gray90'; col.bg = 'white'; 
+  theme_custom(base_size             = base_size, 
+               base_family           = base_family, 
+               tern.plot.background  = NULL, 
+               tern.panel.background = col.bg,
+               col.T                 = col.T,
+               col.L                 = col.L,
+               col.R                 = col.R,
+               col.grid.minor        = col.bg.strip) +
+    theme(text                       = element_text(color = col.text),
+          strip.background           = element_rect(color = col.text, fill = col.bg.strip),
+          strip.text                 = element_text(color = col.text),
+          tern.axis.arrow.show       = TRUE)
+}
+
+#' @rdname ggtern_themes
+#' @export
+theme_bluedark = function(base_size = 12, base_family = ""){
+  featA = 'white'; featAG = 'white'; featB = NA; 
+  featC = '#000080'; featD = '#000040'; featE = '#000060'
+  theme_custom(base_size             = base_size, 
+               base_family           = base_family, 
+               tern.plot.background  = NULL, #FORCE INHERIT
+               tern.panel.background = featC,
+               col.T                 = featA,
+               col.L                 = featA,
+               col.R                 = featA,
+               col.grid.minor        = featB) +
+    theme(text                    = element_text(color = featA),
+          plot.background         = element_rect(fill  = featD),
+          strip.background        = element_rect(color = featA, fill = featE, size=1),
+          strip.text              = element_text(color = featA),
+          tern.panel.grid.major.T = element_line(color = featAG),
+          tern.panel.grid.major.L = element_line(color = featAG),
+          tern.panel.grid.major.R = element_line(color = featAG),
+          tern.axis.arrow.show    = TRUE)
+}
+
+#' @rdname ggtern_themes
+#' @export
+theme_bluelight = function(base_size = 12, base_family = ""){
+  featA = '#000040'; featAG = 'white'; featB = NA; 
+  featC = '#000080'; featD = 'white'; featE = 'white'
+  theme_custom(base_size             = base_size, 
+               base_family           = base_family, 
+               tern.plot.background  = NULL, #FORCE INHERIT
+               tern.panel.background = featC,
+               col.T                 = featA,
+               col.L                 = featA,
+               col.R                 = featA,
+               col.grid.minor        = featB) +
+    theme(text                    = element_text(color = featA),
+          plot.background         = element_rect(fill  = featD),
+          strip.background        = element_rect(color = featC, fill = featE, size=1),
+          strip.text              = element_text(color = featC),
+          tern.panel.grid.major.T = element_line(color = featAG),
+          tern.panel.grid.major.L = element_line(color = featAG),
+          tern.panel.grid.major.R = element_line(color = featAG),
+          tern.axis.arrow.show    = TRUE)
+}
+
+
+#' @rdname ggtern_themes
+#' @export
+theme_bvbw  <- function(base_size = 12, base_family = ""){
+  #Start with grey theme, then overwrite with custom theme
+  col.T = rgb2hex(0,0,0)
+  col.L = rgb2hex(213,94,0)
+  col.R = rgb2hex(0,114,178)
+  theme_custom(base_size,base_family,col.T=col.T,col.L=col.L,col.R=col.R) +
+    
+    #Add, not replace
+    theme(
+      tern.panel.background  = element_rect(fill  = 'white'),
+      tern.panel.grid.minor  = element_line(color = "gray90"),
+      tern.axis.arrow.show   = TRUE
+    )
+}
+
+#' @rdname ggtern_themes
+#' @export
+theme_bvbg <- function(base_size = 12, base_family = ""){
+  
+  #Start with theme_bvbw  theme, and modify slightly
+  theme_bvbw(base_size, base_family) + 
+    
+    #Add to, not replace
+    theme(
+      tern.panel.background  = element_rect(fill  = 'gray92'),
+      tern.panel.grid.minor  = element_line(color = "white")
+    )
+}
+
 #-------------------------------------------------------------
 # REDUNDANT THEMES
 #-------------------------------------------------------------
